**this file will be overwriten! **

 - Write documentation describing your app, files starting __ are ignored.

 - or add to `links.json`

## Settings

 - *activation*: <i>example_2d_scan</i>

 - *run_state*: None

 - *progress*: None

 - *profile*: Run a profile on the run to find performance problems

 - *h0*: None

 - *h1*: None

 - *v0*: None

 - *v1*: None

 - *dh*: None

 - *dv*: None

 - *Nh*: None

 - *Nv*: None

 - *h_center*: None

 - *v_center*: None

 - *h_span*: None

 - *v_span*: None

 - *scan_type*: None

 - *continuous_scan*: None

 - *save_h5*: None

 - *show_previous_scans*: None

 - *n_frames*: None

 - *pixel_time*: None

 - *line_time*: None

 - *frame_time*: None

 - *total_time*: None

 - *h_axis*: None

 - *v_axis*: None

